#!/usr/bin/env python3

import sys
import subprocess
import numpy as np
#from astropy.io import fits
from astropy.time import Time

def jd_bessel(jd):
    return 1900.0 + (jd - 2415020.31352) / 365.242198781

def bessel_jd(bessel):
    return (bessel - 1900.0) * 365.242198781 + 2415020.31352

def main():

    dataset = int(sys.argv[1])
    f = open(sys.argv[2], "r")

    print("# JD (TDB, no lite) & flux_Rc [mag] & sigma [mag] & dataset & Besselian year (UTC, no lite)")

    f3 = open("TLIST", "w")

    i = 0
    for line in f.readlines():
        if line[0:1] == '#': 
            continue
        l = line.split()
        jd_nolite = float(l[0])
        mag = float(l[1])
        sigma_mag = float(l[2])

# lite WAS applied to the input data!!
#        jd_nolite = jd_lite-lite[i]

        t1 = Time(jd_nolite, format="jd", scale="utc")
        t2 = t1.tdb

        bessel = jd_bessel(t1.jd)

        zero = 0.0
        mag = mag + zero
#        mag = -2.5*np.log10(flux/calibration_flux)
#        sigma_mag = mag + 2.5*np.log10((flux+sigma)/calibration_flux)

        print("%.8f  %12.8f  %.8f  %d  %.8f" % (t2.jd, mag, sigma_mag, dataset, bessel))
        f3.write("'%.8f'\n" % (t1.jd))
        i += 1

    f.close()
    f3.close()

if __name__ == "__main__":
    main()


